@@ -6,10 +6,10 @@ from models import (Journal, Tag, Template)
 import django.db.models
 from django.conf import settings
 
-from decorator import commit_on_success
+from decorator import atomic
 
 __all__ = ('record', 'error_record', 'Journal')
-__version__ = '1.22.0'
+__version__ = '1.23.0'
 
 def unicode_truncate(s, length, encoding='utf-8'):
     '''Truncate an unicode string so that its UTF-8 encoding is less than
@@ -17,7 +17,7 @@ def unicode_truncate(s, length, encoding='utf-8'):
     encoded = s.encode(encoding)[:length]
     return encoded.decode(encoding, 'ignore')
 
-@commit_on_success
+@atomic
 def record(tag, template, using=None, **kwargs):
     '''Record an event in the journal. The modification is done inside the
        current transaction.
